@@ -11,7 +11,7 @@ import (
 	"github.com/DCSO/fever/types"
 	"github.com/DCSO/fever/util"
 
-	"github.com/garyburd/redigo/redis"
+	"github.com/gomodule/redigo/redis"
 	log "github.com/sirupsen/logrus"
 )
 
