@@ -31,7 +31,6 @@ type BloomHandler struct {
 	BloomFileIsCompressed bool
 	DatabaseEventChan     chan types.Entry
 	ForwardHandler        Handler
-	DoForwardAlert        bool
 	AlertPrefix           string
 	Alertifier            *util.Alertifier
 	BlacklistIOCs         map[string]struct{}
@@ -75,7 +74,6 @@ func MakeBloomHandler(iocBloom *bloom.BloomFilter,
 		IocBloom:          iocBloom,
 		DatabaseEventChan: databaseChan,
 		ForwardHandler:    forwardHandler,
-		DoForwardAlert:    (util.ForwardAllEvents || util.AllowType("alert")),
 		AlertPrefix:       alertPrefix,
 		Alertifier:        util.MakeAlertifier(alertPrefix),
 		BlacklistIOCs:     make(map[string]struct{}),
@@ -84,6 +82,7 @@ func MakeBloomHandler(iocBloom *bloom.BloomFilter,
 	bh.Alertifier.RegisterMatchType("dns-req", util.AlertJSONProviderDNSReq{})
 	bh.Alertifier.RegisterMatchType("dns-resp", util.AlertJSONProviderDNSResp{})
 	bh.Alertifier.RegisterMatchType("tls-sni", util.AlertJSONProviderTLSSNI{})
+	bh.Alertifier.RegisterMatchType("tls-fingerprint", util.AlertJSONProviderTLSFingerprint{})
 	bh.Alertifier.RegisterMatchType("http-host", util.AlertJSONProviderHTTPHost{})
 	bh.Alertifier.RegisterMatchType("http-url", util.AlertJSONProviderHTTPURL{})
 	log.WithFields(log.Fields{
@@ -99,8 +98,9 @@ func MakeBloomHandlerFromFile(bloomFilename string, compressed bool,
 	databaseChan chan types.Entry, forwardHandler Handler, alertPrefix string,
 	blacklistIOCs []string) (*BloomHandler, error) {
 	log.WithFields(log.Fields{
-		"domain": "bloom",
-	}).Infof("loading Bloom filter '%s'", bloomFilename)
+		"domain":   "bloom",
+		"filename": bloomFilename,
+	}).Info("loading Bloom filter from file")
 	iocBloom, err := bloom.LoadFilter(bloomFilename, compressed)
 	if err != nil {
 		if err == io.EOF {
@@ -124,7 +124,7 @@ func MakeBloomHandlerFromFile(bloomFilename string, compressed bool,
 	}
 	bh.BloomFilename = bloomFilename
 	bh.BloomFileIsCompressed = compressed
-	bh.Logger.Info("filter loaded successfully", bloomFilename)
+	bh.Logger.WithFields(log.Fields{}).Info("filter file loaded successfully")
 	return bh, nil
 }
 
@@ -274,6 +274,16 @@ func (a *BloomHandler) Consume(e *types.Entry) error {
 					log.Warn(err)
 				}
 			}
+		} else if a.IocBloom.Check([]byte(e.TLSFingerprint)) {
+			if _, present := a.BlacklistIOCs[e.TLSFingerprint]; !present {
+				if n, err := a.Alertifier.MakeAlert(*e, e.TLSFingerprint,
+					"tls-fingerprint"); err == nil {
+					a.DatabaseEventChan <- *n
+					a.ForwardHandler.Consume(n)
+				} else {
+					log.Warn(err)
+				}
+			}
 		}
 		a.Unlock()
 	}
