@@ -142,13 +142,19 @@ func (c *Consumer) Shutdown() error {
 	return <-c.done
 }
 
+const maxLogLen = 100
+
 func handle(deliveries <-chan wabbit.Delivery, done chan error, callback func(wabbit.Delivery)) {
 	for d := range deliveries {
+		v := d.Body()
+		if len(v) > maxLogLen {
+			v = v[:maxLogLen]
+		}
 		log.Debugf(
 			"got %dB delivery: [%v] %q",
 			len(d.Body()),
 			d.DeliveryTag(),
-			d.Body(),
+			v,
 		)
 		callback(d)
 		d.Ack(false)
